package com.perforce.spark.navigation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;

import spark.Request;

import com.perforce.spark.artifact.ArtifactType;
import com.perforce.spark.connection.ConnectionSession;

public class NavBar {

	private static SortedMap<String, NavBarInterface> map = new TreeMap<>();

	static {
		add(new NavBarMenu("Browse", "browse", false));
		add(new NavBarMenu("Search", "search", false));

		NavBarMenu deploy = new NavBarMenu("Deploy", "deploy", true);
		for (ArtifactType type : ArtifactType.list()) {
			String path = "/deploy/" + type.getId();
			ListItem item = new ListItem(type.getTitle(), path);
			deploy.add(item);
		}
		add(deploy);

		add(new NavBarConfig("Configuration", "config", false));
	}

	public static void add(NavBarInterface item) {
		String id = item.getPage();
		map.put(id, item);
	}

	public static Map<String, Object> attributes(String selected,
			Request request) {

		Map<String, Object> attributes = new HashMap<>();

		attributes.put("navBar", navBar(selected));
		attributes.put("title", title(selected));
		attributes.put("login", ConnectionSession.isValid(request));
		attributes.put("config", map.get("config").isActive());
		attributes.put("error_show", "none");
		attributes.put("error_message", "");
		return attributes;
	}

	private static ArrayList<NavBarMenu> navBar(String selected) {
		ArrayList<NavBarMenu> items = new ArrayList<>();
		for (String id : map.keySet()) {
			NavBarInterface item = map.get(id);
			if (id.equals(selected)) {
				item.setActive(true);
			} else {
				item.setActive(false);
			}
			if (item instanceof NavBarMenu) {
				items.add((NavBarMenu) item);
			}
		}
		return items;
	}

	private static String title(String id) {
		String title = "";
		if (map.containsKey(id)) {
			title = map.get(id).getTitle();
		}
		return title;
	}
}
